@@ -14,7 +14,7 @@ use Plack::Util::Accessor qw/ client sample_rate /;
 use POSIX ();
 use Time::HiRes;
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 sub call {
     my ( $self, $env ) = @_;
@@ -50,6 +50,7 @@ sub call {
 
             if ( my $type = $env->{CONTENT_TYPE} ) {
                 $type =~ s#/#.#g;
+                $type =~ s/;.*$//;
                 $client->increment( 'psgi.request.content-type.' . $type,
                     $rate );
 
@@ -73,6 +74,7 @@ sub call {
 
             if ( my $type = $h->get('Content-Type') ) {
                 $type =~ s#/#.#g;
+                $type =~ s/;.*$//;
                 $client->increment( 'psgi.response.content-type.' . $type,
                     $rate );
             }
@@ -109,7 +111,7 @@ Plack::Middleware::Statsd - send statistics to statsd
 
 =head1 VERSION
 
-version v0.1.0
+version v0.1.1
 
 =head1 SYNOPSIS
 
@@ -186,7 +188,7 @@ set_add
 
 Other statsd client modules may be used via a wrapper class.
 
-=head2 C<sample_rate>
+=head2 sample_rate
 
 The default sampling rate to used. This will override the default rate
 of the L</client>.
@@ -199,34 +201,34 @@ The following metrics are logged:
 
 =over
 
-=item psgi.request.method.$METHOD
+=item C<psgi.request.method.$METHOD>
 
 This increments a counter for the request method.
 
-=item psgi.request.remote_addr
+=item C<psgi.request.remote_addr>
 
 The remote address is added to the set.
 
-=item psgi.request.content-length
+=item C<psgi.request.content-length>
 
 The content-length of the request, if it is specified in the header.
 
 This is treated as a timing rather than a counter, so that statistics
 can be saved.
 
-=item psgi.response.content-length
+=item C<psgi.response.content-length>
 
 The content-length of the response, if it is specified in the header.
 
 This is treated as a timing rather than a counter, so that statistics
 can be saved.
 
-=item psgi.response.content-type.$TYPE.$SUBTYPE
+=item C<psgi.response.content-type.$TYPE.$SUBTYPE>
 
 A counter for the content type is incremented, e.g. for a JPEG image,
 the counter C<psgi.response.content-type.image.jpeg> is incremented.
 
-=item psgi.response.status.$CODE
+=item C<psgi.response.status.$CODE>
 
 A counter for the HTTP status code is incremented.
 
@@ -234,6 +236,14 @@ A counter for the HTTP status code is incremented.
 
 The response time, in ms (rounded up using C<ceil>).
 
+=item C<psgi.response.x-sendfile>
+
+This counter is incremented when the C<X-Sendfile> header is added.
+
+=item C<psgix.harakiri>
+
+This counter is incremented when the harakiri flag is set.
+
 =back
 
 If you want to rename these, then you will need to use a wrapper
